# Security Policy

## Supported Versions

Only the latest version within each major release (we use semantic versioning: [https://semver.org/](https://semver.org/)) is supported for security updates. This should be sufficient for most use cases, as each minor and patch version is backwards compatible.

## Reporting a Vulnerability

Please report vulnerabilities under the [security tab](https://github.com/Christopher-K-Long/QuGrad/security) or email Christopher K. Long at [ckl45@cam.ac.uk](mailto:ckl45@cam.ac.uk?subject=Security%20Vulnerability%20in%20QuGrad).
